@@ -1,5 +1,4 @@
 from django.apps import AppConfig
-from wagtail.users.apps import WagtailUsersAppConfig
 
 
 class WagtailTenantsConfig(AppConfig):
@@ -7,4 +6,10 @@ class WagtailTenantsConfig(AppConfig):
     name = "wagtail_tenants"
 
     def ready(self):
+        from wagtail.users.apps import WagtailUsersAppConfig
+
         import wagtail_tenants.signals  # noqa
+
+        WagtailUsersAppConfig.group_viewset = (
+            "wagtail_tenants.views.TenantAwareGroupViewSet"
+        )
