@@ -6,12 +6,15 @@ from django.utils.translation import gettext as _
 from django_tenants.utils import tenant_context
 from wagtail.admin import messages
 from wagtail.admin.views import account
-from wagtail.core.log_actions import log
+from wagtail.log_actions import log
+from wagtail.users.views.groups import CreateView, EditView, GroupViewSet
 
 from wagtail_tenants.backends import UserModel
 from wagtail_tenants.forms import TenantAdminUserForm
 from wagtail_tenants.utils import check_tenant_for_user
 
+from .forms import TenantAwareGroupForm
+
 
 class TenantLoginView(account.LoginView):
     def get(self, *args, **kwargs):
@@ -76,7 +79,7 @@ class TenantUserAdmin:
                         ],
                     )
                     return redirect("wagtail-tenants__admin_link")
-                
+
         else:
             form = TenantAdminUserForm()
             return TemplateResponse(
@@ -86,3 +89,35 @@ class TenantUserAdmin:
                     "form": form,
                 },
             )
+
+
+class TenantAwareGroupCreateView(CreateView):
+    def get_form_kwargs(self):
+        """Passes the user to the form class.
+        This is necessary to only display members that belong to a given user
+        """
+
+        kwargs = super(CreateView, self).get_form_kwargs()
+        kwargs["user"] = self.request.user
+        kwargs["tenant"] = self.request.tenant
+        return kwargs
+
+
+class TenantAwareGroupEditView(EditView):
+    def get_form_kwargs(self):
+        """Passes the user to the form class.
+        This is necessary to only display members that belong to a given user
+        """
+
+        kwargs = super(EditView, self).get_form_kwargs()
+        kwargs["user"] = self.request.user
+        kwargs["tenant"] = self.request.tenant
+        return kwargs
+
+
+class TenantAwareGroupViewSet(GroupViewSet):
+    add_view_class = TenantAwareGroupCreateView
+    edit_view_class = TenantAwareGroupEditView
+
+    def get_form_class(self, for_update=False):
+        return TenantAwareGroupForm
